<?php

namespace AuthStack\Installer\Model;


use Buckhill\Support\Traits\DotNotationAccessorTrait;

class License
{
    use DotNotationAccessorTrait;

    protected $model;

    public function __construct(array $model)
    {
        $this->model = $model;
    }

    public function toArray()
    {
        return [
            'id'        => 1,
            'license'   => $this->dotNotationFromModel('license'),
            'domain'    => $this->dotNotationFromModel('domain'),
            'endsAt'    => $this->dotNotationFromModel('endsAt')
        ];
    }

}