<?php

namespace AuthStack\Installer\Provider;

use Illuminate\Support\ServiceProvider;
use AuthStack\Installer\Services\MySQL;


class MySQLConnectionCheckerProvider extends ServiceProvider
{
    public function register()
    {
        return $this->app->singleton('MySQLConnectionChecker', function($app)
        {
            return new MySQL;
        });
    }
}